Learn R Programming

obliclus (version 0.9)

criteria: The value of the objective function which is minimized.

Description

The value of the objective function of Obliclus is calculated. In criteria, two different rotation criteria, Oblimin and Geomin, can be calculated in the objective function of Obliclus.

Usage

criteria(A, T, cluster, info)

Arguments

A
The loading matrix for rotation.
T
The current value of rotation matrix.
cluster
The vector of cluster parameters which indicate a cluster where each variable is assigned.
info
The list including N.cluster the number of clusters, N.var the number of observed variables, method a rotation method whose criterion is included in an objective function, and the value of an specific parameter to a rotation method, for example, the value of oblimin parameter for the method oblimin.

Value

The value of the objective function given A, T, and cluster.

References

Yamamoto, M. and Jennrich, R.I. (2012). A cluster-based factor rotation. submitted.

See Also

obliclus