criteria, two different rotation criteria, Oblimin and Geomin,
can be calculated in the objective function of Obliclus.
criteria(A, T, cluster, info)N.cluster the number of
clusters, N.var the number of observed variables,
method a rotation method whose criterion is included in an
objective function, and the value of an specific parameter to a
rotation method, for example, the value of oblimin parameter for the
method oblimin.
A, T, and
cluster.
obliclus